==> qlcplus_4.12.2.orig.tar.xz: qlcplus-QLC-_4.12.2/plugins/midi/src/MIDI_pt_BR.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt_PT">
<context>
    <name>ConfigureMidiPlugin</name>
    <message>
        <location filename="common/configuremidiplugin.ui" line="33"/>
        <source>Configure MIDI Plugin</source>
        <translation>Configurar o plugin MIDI</translation>
    </message>
    <message>
        <location filename="common/configuremidiplugin.ui" line="66"/>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <location filename="common/configuremidiplugin.ui" line="71"/>
        <source>MIDI Channel</source>
        <translation>Canal MIDI</translation>
    </message>
    <message>
        <location filename="common/configuremidiplugin.ui" line="76"/>
        <source>Mode</source>
        <translation>Modo</translation>
    </message>
    <message>
        <location filename="common/configuremidiplugin.ui" line="81"/>
        <source>Init Message</source>
        <translation>Mensagem Init</translation>
    </message>
    <message>
        <location filename="common/configuremidiplugin.ui" line="39"/>
        <source>Refresh</source>
        <translation>Actualizar</translation>
    </message>
    <message>
        <location filename="common/configuremidiplugin.cpp" line="127"/>
        <source>Outputs</source>
        <translation>Saídas</translation>
    </message>
    <message>
        <location filename="common/configuremidiplugin.cpp" line="150"/>
        <source>Inputs</source>
        <translation>Entradas</translation>
    </message>
    <message>
        <location filename="common/configuremidiplugin.cpp" line="214"/>
        <source>None</source>
        <translation>Nenhum</translation>
    </message>
</context>
<context>
    <name>MidiPlugin</name>
    <message>
        <location filename="common/midiplugin.cpp" line="139"/>
        <source>This plugin provides input/output support for MIDI devices.</source>
        <translation>Este plugin fornece suporte de Entrada/Saída para dispositivos MIDI.</translation>
    </message>
    <message>
        <location filename="common/midiplugin.cpp" line="153"/>
        <source>No output support available.</source>
        <translation>Suporte de saída não disponível</translation>
    </message>
    <message>
        <location filename="common/midiplugin.cpp" line="161"/>
        <source>Output</source>
        <translation>Saída</translation>
    </message>
    <message>
        <location filename="common/midiplugin.cpp" line="164"/>
        <location filename="common/midiplugin.cpp" line="272"/>
        <source>Open</source>
        <translation>Aberto</translation>
    </message>
    <message>
        <location filename="common/midiplugin.cpp" line="166"/>
        <location filename="common/midiplugin.cpp" line="274"/>
        <source>Not Open</source>
        <translation>Não aberto</translation>
    </message>
    <message>
        <location filename="common/midiplugin.cpp" line="167"/>
        <location filename="common/midiplugin.cpp" line="275"/>
        <source>Status</source>
        <translation>Estado</translation>
    </message>
    <message>
        <location filename="common/midiplugin.cpp" line="173"/>
        <source>Invalid Output</source>
        <translation>Saída inválida</translation>
    </message>
    <message>
        <location filename="common/midiplugin.cpp" line="261"/>
        <source>No input support available.</source>
        <translation>Suporte de entrada não disponível</translation>
    </message>
    <message>
        <location filename="common/midiplugin.cpp" line="269"/>
        <source>Input</source>
        <translation>Entrada</translation>
    </message>
    <message>
        <location filename="common/midiplugin.cpp" line="281"/>
        <source>Invalid Input</source>
        <translation>Entrada inválida</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../engine/src/qlcfile.cpp" line="196"/>
        <source>No error occurred.</source>
        <translation>Sem erros</translation>
    </message>
    <message>
        <location filename="../../engine/src/qlcfile.cpp" line="198"/>
        <source>An error occurred when reading from the file.</source>
        <translation>Ocorreu um erro ao ler o ficheiro</translation>
    </message>
    <message>
        <location filename="../../engine/src/qlcfile.cpp" line="200"/>
        <source>An error occurred when writing to the file.</source>
        <translation>Ocorreu um erro ao guardar para o ficheiro</translation>
    </message>
    <message>
        <location filename="../../engine/src/qlcfile.cpp" line="202"/>
        <source>A fatal error occurred.</source>
        <translation>Ocorreu um erro fatal.</translation>
    </message>
    <message>
        <location filename="../../engine/src/qlcfile.cpp" line="204"/>
        <source>Resource error occurred.</source>
        <translation>Ocorreu um erro de recursos.</translation>
    </message>
    <message>
        <location filename="../../engine/src/qlcfile.cpp" line="206"/>
        <source>The file could not be opened.</source>
        <translation>O ficheiro não pode ser aberto</translation>
    </message>
    <message>
        <location filename="../../engine/src/qlcfile.cpp" line="208"/>
        <source>The operation was aborted.</source>
        <translation>Operação abortada</translation>
    </message>
    <message>
        <location filename="../../engine/src/qlcfile.cpp" line="210"/>
        <source>A timeout occurred.</source>
        <translation>Passou o tempo.</translation>
    </message>
    <message>
        <location filename="../../engine/src/qlcfile.cpp" line="212"/>
        <source>An unspecified error occurred.</source>
        <translation>Ocorreu um erro não especificado.</translation>
    </message>
    <message>
        <location filename="../../engine/src/qlcfile.cpp" line="214"/>
        <source>The file could not be removed.</source>
        <translation>O ficheiro não pode ser eliminado.</translation>
    </message>
    <message>
        <location filename="../../engine/src/qlcfile.cpp" line="216"/>
        <source>The file could not be renamed.</source>
        <translation>O ficheiro não pode ser renomeado.</translation>
    </message>
    <message>
        <location filename="../../engine/src/qlcfile.cpp" line="218"/>
        <source>The position in the file could not be changed.</source>
        <translation>A posição no arquivo não pode ser alterada.</translation>
    </message>
    <message>
        <location filename="../../engine/src/qlcfile.cpp" line="220"/>
        <source>The file could not be resized.</source>
        <translation>Não se pode alterar o tamanho do ficheiro.</translation>
    </message>
    <message>
        <location filename="../../engine/src/qlcfile.cpp" line="222"/>
        <source>The file could not be accessed.</source>
        <translation>Não se pode aceder ao ficheiro.</translation>
    </message>
    <message>
        <location filename="../../engine/src/qlcfile.cpp" line="224"/>
        <source>The file could not be copied.</source>
        <translation>O ficheiro não pode ser copiado.</translation>
    </message>
    <message>
        <location filename="../../engine/src/qlcfile.cpp" line="226"/>
        <source>An unknown error occurred.</source>
        <translation>Ocorreu um erro desconhecido.</translation>
    </message>
</context>
</TS>

==> qlcplus_4.12.7.orig.tar.xz: qlcplus-QLC-_4.12.7/plugins/midi/src/MIDI_pt_BR.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt_PT">
<context>
    <name>ConfigureMidiPlugin</name>
    <message>
        <location filename="common/configuremidiplugin.ui" line="33"/>
        <source>Configure MIDI Plugin</source>
        <translation>Configurar o plugin MIDI</translation>
    </message>
    <message>
        <location filename="common/configuremidiplugin.ui" line="66"/>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <location filename="common/configuremidiplugin.ui" line="71"/>
        <source>MIDI Channel</source>
        <translation>Canal MIDI</translation>
    </message>
    <message>
        <location filename="common/configuremidiplugin.ui" line="76"/>
        <source>Mode</source>
        <translation>Modo</translation>
    </message>
    <message>
        <location filename="common/configuremidiplugin.ui" line="81"/>
        <source>Init Message</source>
        <translation>Mensagem Init</translation>
    </message>
    <message>
        <location filename="common/configuremidiplugin.ui" line="39"/>
        <source>Refresh</source>
        <translation>Actualizar</translation>
    </message>
    <message>
        <location filename="common/configuremidiplugin.cpp" line="127"/>
        <source>Outputs</source>
        <translation>Saídas</translation>
    </message>
    <message>
        <location filename="common/configuremidiplugin.cpp" line="150"/>
        <source>Inputs</source>
        <translation>Entradas</translation>
    </message>
    <message>
        <location filename="common/configuremidiplugin.cpp" line="214"/>
        <source>None</source>
        <translation>Nenhum</translation>
    </message>
</context>
<context>
    <name>MidiPlugin</name>
    <message>
        <location filename="common/midiplugin.cpp" line="139"/>
        <source>This plugin provides input/output support for MIDI devices.</source>
        <translation>Este plugin fornece suporte de Entrada/Saída para dispositivos MIDI.</translation>
    </message>
    <message>
        <location filename="common/midiplugin.cpp" line="153"/>
        <source>No output support available.</source>
        <translation>Suporte de saída não disponível</translation>
    </message>
    <message>
        <location filename="common/midiplugin.cpp" line="161"/>
        <source>Output</source>
        <translation>Saída</translation>
    </message>
    <message>
        <location filename="common/midiplugin.cpp" line="164"/>
        <location filename="common/midiplugin.cpp" line="272"/>
        <source>Open</source>
        <translation>Aberto</translation>
    </message>
    <message>
        <location filename="common/midiplugin.cpp" line="166"/>
        <location filename="common/midiplugin.cpp" line="274"/>
        <source>Not Open</source>
        <translation>Não aberto</translation>
    </message>
    <message>
        <location filename="common/midiplugin.cpp" line="167"/>
        <location filename="common/midiplugin.cpp" line="275"/>
        <source>Status</source>
        <translation>Estado</translation>
    </message>
    <message>
        <location filename="common/midiplugin.cpp" line="173"/>
        <source>Invalid Output</source>
        <translation>Saída inválida</translation>
    </message>
    <message>
        <location filename="common/midiplugin.cpp" line="261"/>
        <source>No input support available.</source>
        <translation>Suporte de entrada não disponível</translation>
    </message>
    <message>
        <location filename="common/midiplugin.cpp" line="269"/>
        <source>Input</source>
        <translation>Entrada</translation>
    </message>
    <message>
        <location filename="common/midiplugin.cpp" line="281"/>
        <source>Invalid Input</source>
        <translation>Entrada inválida</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../../engine/src/qlcfile.cpp" line="112"/>
        <source>No error occurred.</source>
        <translation>Sem erros</translation>
    </message>
    <message>
        <location filename="../../../engine/src/qlcfile.cpp" line="114"/>
        <source>An error occurred when reading from the file.</source>
        <translation>Ocorreu um erro ao ler o ficheiro</translation>
    </message>
    <message>
        <location filename="../../../engine/src/qlcfile.cpp" line="116"/>
        <source>An error occurred when writing to the file.</source>
        <translation>Ocorreu um erro ao guardar para o ficheiro</translation>
    </message>
    <message>
        <location filename="../../../engine/src/qlcfile.cpp" line="118"/>
        <source>A fatal error occurred.</source>
        <translation>Ocorreu um erro fatal.</translation>
    </message>
    <message>
        <location filename="../../../engine/src/qlcfile.cpp" line="120"/>
        <source>Resource error occurred.</source>
        <translation>Ocorreu um erro de recursos.</translation>
    </message>
    <message>
        <location filename="../../../engine/src/qlcfile.cpp" line="122"/>
        <source>The file could not be opened.</source>
        <translation>O ficheiro não pode ser aberto</translation>
    </message>
    <message>
        <location filename="../../../engine/src/qlcfile.cpp" line="124"/>
        <source>The operation was aborted.</source>
        <translation>Operação abortada</translation>
    </message>
    <message>
        <location filename="../../../engine/src/qlcfile.cpp" line="126"/>
        <source>A timeout occurred.</source>
        <translation>Passou o tempo.</translation>
    </message>
    <message>
        <location filename="../../../engine/src/qlcfile.cpp" line="128"/>
        <source>An unspecified error occurred.</source>
        <translation>Ocorreu um erro não especificado.</translation>
    </message>
    <message>
        <location filename="../../../engine/src/qlcfile.cpp" line="130"/>
        <source>The file could not be removed.</source>
        <translation>O ficheiro não pode ser eliminado.</translation>
    </message>
    <message>
        <location filename="../../../engine/src/qlcfile.cpp" line="132"/>
        <source>The file could not be renamed.</source>
        <translation>O ficheiro não pode ser renomeado.</translation>
    </message>
    <message>
        <location filename="../../../engine/src/qlcfile.cpp" line="134"/>
        <source>The position in the file could not be changed.</source>
        <translation>A posição no arquivo não pode ser alterada.</translation>
    </message>
    <message>
        <location filename="../../../engine/src/qlcfile.cpp" line="136"/>
        <source>The file could not be resized.</source>
        <translation>Não se pode alterar o tamanho do ficheiro.</translation>
    </message>
    <message>
        <location filename="../../../engine/src/qlcfile.cpp" line="138"/>
        <source>The file could not be accessed.</source>
        <translation>Não se pode aceder ao ficheiro.</translation>
    </message>
    <message>
        <location filename="../../../engine/src/qlcfile.cpp" line="140"/>
        <source>The file could not be copied.</source>
        <translation>O ficheiro não pode ser copiado.</translation>
    </message>
    <message>
        <location filename="../../../engine/src/qlcfile.cpp" line="142"/>
        <source>An unknown error occurred.</source>
        <translation>Ocorreu um erro desconhecido.</translation>
    </message>
</context>
</TS>
